@@ -1,6 +1,5 @@
-package # hide from PAUSE
-    Starch::Plugin::Net::Statsd::Manager;
-
+package Starch::Plugin::Net::Statsd::Manager;
+$Starch::Plugin::Net::Statsd::Manager::VERSION = '0.02';
 use Types::Common::String -types;
 use Types::Common::Numeric -types;
 
